==> menta-queue-0.9.2-sources.jar: org/mentaqueue/BrokenFastQueue.java <==
/*
 * MentaQueue => http://mentaqueue.soliveirajr.com
 * Copyright (C) 2012  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentaqueue;

import org.mentaqueue.util.Builder;

public class BrokenFastQueue<E> implements Queue<E> {

	private final E[] data;

	@SuppressWarnings("unchecked")
	public BrokenFastQueue(Builder<E> builder) {
		this.data = (E[]) new Object[1];
		this.data[0] = builder.newInstance();
	}
	
	private final static <E> Builder<E> createBuilder(final Class<E> klass) {
		return new Builder<E>() {
			@Override
            public E newInstance() {
	            try {
	            	return klass.newInstance();
	            } catch(Exception e) {
	            	throw new RuntimeException(e);
	            }
            }
		};
	}
	
	public BrokenFastQueue(Class<E> klass) {
		this(createBuilder(klass));
	}
	
	@Override
	public final E nextToOffer() {
		return data[0];
	}

	@Override
	public final void offer(E e) {
		// NOOP
	}

	@Override
	public final long available() {
		return 1;
	}

	@Override
	public final E poll() {
		return data[0];
	}

	@Override
	public final void done() {
		// NOOP
	}
}

==> menta-queue-0.9.3-sources.jar: org/mentaqueue/BrokenFastQueue.java <==
/*
 * MentaQueue => http://mentaqueue.soliveirajr.com
 * Copyright (C) 2012  Sergio Oliveira Jr. (sergio.oliveira.jr@gmail.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package org.mentaqueue;

import static org.mentaqueue.util.BuilderUtils.*;

import org.mentaqueue.util.Builder;

public class BrokenFastQueue<E> implements Queue<E> {

	private final E[] data;

	@SuppressWarnings("unchecked")
	public BrokenFastQueue(Builder<E> builder) {
		this.data = (E[]) new Object[1];
		this.data[0] = builder.newInstance();
	}
	
	public BrokenFastQueue(Class<E> klass) {
		this(createBuilder(klass));
	}
	
	@Override
	public final E nextToOffer() {
		return data[0];
	}

	@Override
	public final void offer(E e) {
		// NOOP
	}

	@Override
	public final long available() {
		return 1;
	}

	@Override
	public final E poll() {
		return data[0];
	}

	@Override
	public final void done() {
		// NOOP
	}
}
